@@ -1,10 +1,10 @@
 #!/usr/bin/env python
-__author__ = ('Nicola Segata (nicola.segata@unitn.it), '
+__author__ = ('Francesco Beghini (francesco.beghini@unitn.it),'
+              'Nicola Segata (nicola.segata@unitn.it), '
               'Duy Tin Truong, '
-              'Francesco Asnicar (f.asnicar@unitn.it), '
-              'Francesco Beghini (francesco.beghini@unitn.it)')
-__version__ = '3.0.1'
-__date__ = '25 Jun 2020'
+              'Francesco Asnicar (f.asnicar@unitn.it)')
+__version__ = '3.0.2'
+__date__ = '23 Jul 2020'
 
 import sys
 try:
@@ -16,6 +16,7 @@ if float(sys.version_info[0]) < 3.0:
     sys.stderr.write("MetaPhlAn requires Python 3, your current Python version is {}.{}.{}\n"
                     .format(sys.version_info[0], sys.version_info[1], sys.version_info[2]))
     sys.exit(1)
+    
 import os
 import stat
 import re
@@ -26,6 +27,7 @@ from glob import glob
 from subprocess import DEVNULL
 import argparse as ap
 import bz2
+import json
 import pickle
 import subprocess as subp
 import tempfile as tf
@@ -54,11 +56,6 @@ try:
 except ImportError:
     sys.stderr.write("Warning! Biom python library not detected!"
                      "\n Exporting to biom format will not work!\n")
-try:
-    import json
-except ImportError:
-    sys.stderr.write("Warning! json python library not detected!"
-                     "\n Exporting to biom format will not work!\n")
 
 # get the directory that contains this script
 metaphlan_script_install_folder = os.path.dirname(os.path.abspath(__file__))
@@ -1004,6 +1001,7 @@ def main():
         os.remove( pars['inp'] )
 
     if ESTIMATE_UNK and pars['input_type'] == 'sam':
+        n_metagenome_reads = pars['nreads']
         if not n_metagenome_reads and not pars['nreads']:
             sys.stderr.write(
                     "Please provide the size of the metagenome using the "
@@ -1181,12 +1179,13 @@ def main():
             cl2pr = tree.clade_profiles( None, get_all = True  )
             cl2ab, _, _ = tree.relative_abundances( None )
             strout = []
-            for clade,v in cl2pr.items():
-                if clade.endswith(pars['clade']) and cl2ab[clade]*100.0 < pars['min_ab']:
+            for (taxstr, taxid), relab in cl2ab.items():
+                clade = taxstr
+                if clade.endswith(pars['clade']) and relab*100.0 < pars['min_ab']:
                     strout = []
                     break
                 if pars['clade'] in clade:
-                    strout += ["\t".join([str(a),str(int(b > pars['pres_th']))]) for a,b in v]
+                    strout += ["\t".join([str(a),str(int(b > pars['pres_th']))]) for a,b in cl2pr[clade]]
             if strout:
                 strout = sorted(strout,key=lambda x:x[0])
                 outf.write( "\n".join(strout) + "\n" )
